@@ -8,37 +8,37 @@
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *  Karsten Ohme <karsten.ohme@inf.tu-dresden.de>
  *
- * $Id: muscleTool.h,v 1.1.1.1 2006-02-07 19:54:07 rousseau Exp $
+ * $Id: muscleTool.h,v 1.1.1.2 2009-11-13 13:13:11 rousseau Exp $
  */
 
 #ifdef _WIN32
 #define PACKAGE_VERSION "2.0.0"
 #endif
 
-void doListTokens();
+void doListTokens(void);
 void doFormat(int tokenNumber);
 void doConnect(int tokenNumber);
-void doRelease();
+void doRelease(void);
 void doMoveKey(int old_key_nb, int new_key_nb);
 void doMove(char *oldObjectID, char *newObjectID);
 void doChangeACL(char *objectID);
-void doListPINs();
-void doList();
-void doListKeys();
+void doListPINs(void);
+void doList(void);
+void doListKeys(void);
 void doChangeKeyACL(int key_nb);
 void doDeleteKey(int key_nb);
-void doStatus();
-void doSetStatus();
+void doStatus(void);
+void doSetStatus(void);
 void doDeleteID(int pin_nb);
-void doLogout();
-void doVersion();
+void doLogout(void);
+void doVersion(void);
 void doVerify(int pinNumber);
 void doChallenge(int len);
 void doUnblockPIN(int pinNumber);
-void doResume(char *type);
+void doResume(const char *type);
 void doMakePIN(int pinNumber, char *pinData, char *pinUnblockData);
 void doChangePIN(int pinNumber);
-void doGenKeys(char *keyType, int keySize);
+void doGenKeys(const char *keyType, int keySize);
 void doExportKey(int keyNumber, char *fileName);
 void doImportKey(int keyNumber, char *fileName);
 void doCrypt(int keyNum, char *inFileName, char *outFileName);
@@ -46,5 +46,5 @@ void doCreate(char *objectID, int objectSize);
 void doDelete(char *objectID);
 void doRead(char *objectID, char *fileName);
 void doWrite(char *fileName, char *objectID);
-void doExit();
+void doExit(void);
 
